.DocSearch-Container {
  z-index: 1050;
}

.search-button__wrapper.show .search-button__overlay,
.search-button__wrapper.show .search-button__search-container {
  display: none;
}

.DocSearch-Hits mark {
  padding: 0;
}
